import TreeView from '@mui/lab/TreeView';
import ArrowRightIcon from '@mui/icons-material/ArrowRight';
import ArrowDropDownIcon from '@mui/icons-material/ArrowDropDown';
import TreeItem from '@mui/lab/TreeItem';


type MyTreeViewProps = {
    treeData: RenderTree
    onNodeFocus?: (event: object, value: string) => void; // 点击某一项的回调
    onNodeSelect?: (event: object, value: Array<any> | string) => void; // 点击某一项的回调
    onNodeToggle?: (event: object, nodeIds: Array<any>) => void; // 点击某一项的回调
    renderLabel?: (labelNmae: string) => React.ReactNode
    treeViewSx?: any
}

interface RenderTree {
    id: string | number;
    name: string;
    children?: readonly RenderTree[];
}


const MyTreeView = (props: MyTreeViewProps) => {
    const {treeData, renderLabel, treeViewSx, onNodeFocus, onNodeSelect, onNodeToggle} = props

    const renderTree = (nodes: RenderTree) => (
        <TreeItem key={nodes.id} nodeId={String(nodes.id)} label={renderLabel === undefined ? nodes.name : renderLabel(nodes.name)}>
            {Array.isArray(nodes.children)
            ? nodes.children.map((node) => renderTree(node))
            : null}
        </TreeItem>
    );

    return (
        <TreeView
        defaultCollapseIcon={<ArrowRightIcon />}
        defaultExpandIcon={<ArrowDropDownIcon />}
        sx={{ treeViewSx }}
        onNodeFocus={onNodeFocus}
        onNodeSelect={onNodeSelect}
        onNodeToggle={onNodeToggle}
        >
            {renderTree(treeData)}
        </TreeView>
    );
};

export default MyTreeView;
